/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __SCRIPT_FU_SCRIPTS_H__
#define __SCRIPT_FU_SCRIPTS_H__


void       script_fu_find_scripts  (const gchar *path);
pointer    script_fu_add_script    (scheme *sc, pointer a);
pointer    script_fu_add_menu      (scheme *sc, pointer a);
void       script_fu_error_msg     (const gchar *command,
                                    const gchar *msg);
gchar   * script_fu_strescape      (const gchar *source);


#endif /*  __SCRIPT_FU_SCRIPTS__  */
